@@ -1,11 +1,11 @@
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Run; # git description: 0.041-2-gf3abdc0
+package Dist::Zilla::Plugin::Run; # git description: 0.043-10-ga61808a
 # ABSTRACT: Run external commands and code at specific phases of Dist::Zilla
 # KEYWORDS: plugin tool distribution build release run command shell execute
 
-our $VERSION = '0.042';
+our $VERSION = '0.044';
 
 1;
 
@@ -21,40 +21,45 @@ Dist::Zilla::Plugin::Run - Run external commands and code at specific phases of
 
 =head1 VERSION
 
-version 0.042
+version 0.044
 
 =head1 SYNOPSIS
 
   [Run::AfterBuild]
-  run = script/do_this.pl --dir %s --version %s
+  run = script/do_this.pl --dir %d --version %v
   run = script/do_that.pl
   eval = unlink scratch.dat
 
   [Run::BeforeBuild]
   fatal_errors = 0
-  run = script/do_this.pl --version %s
+  run = script/do_this.pl --version %v
   run = script/do_that_crashy_thing.pl
   eval = if ($ENV{SOMETHING}) {
   eval =   $_[0]->log('some message')
   eval = }
 
+  [Run::BeforeArchive]
+  run = script/myapp_before1.pl %d %v
+  run = script/myapp_before2.pl %n %v
+  run_no_trial = script/no_execution_on_trial.pl %n %v
+
   [Run::BeforeRelease]
-  run = script/myapp_before1.pl %s
+  run = script/myapp_before1.pl %a
   run = script/myapp_before2.pl %n %v
   run_no_trial = script/no_execution_on_trial.pl %n %v
 
   [Run::Release]
-  run = script/myapp_deploy1.pl %s
+  run = script/myapp_deploy1.pl %a
   run = deployer.pl --dir %d --tgz %a --name %n --version %v
   run_no_trial = script/no_execution_on_trial.pl --dir %d --tgz %a --name %n --version %v
 
   [Run::AfterRelease]
-  run = script/myapp_after.pl --archive %s --version %s
+  run = script/myapp_after.pl --archive %a --dir %d --version %v
   ; %p can be used as the path separator if you have contributors on a different OS
-  run = script%pmyapp_after.pl --archive %s --version %s
+  run = script%pmyapp_after.pl --archive %a --dir %d --version %v
 
   [Run::AfterRelease / MyAppAfter]
-  run = script/myapp_after.pl --archive %s --version %s
+  run = script/myapp_after.pl --archive %a --dir %d --version %v
 
   [Run::Test]
   run = script/tester.pl --name %n --version %v some_file.ext
@@ -142,19 +147,19 @@ C<%a> the archive of the release (available to all C<*Release> phases)
 
 =item *
 
-C<%d> the directory in which the dist was built (or minted) (not in C<BeforeBuild>)
+C<%d> the directory in which the distribution was built (or minted) (not in C<BeforeBuild>)
 
 =item *
 
-C<%n> the dist name
+C<%n> the distribution name
 
 =item *
 
-C<%p> path separator ('/' on Unix, '\\' on Win32... useful for cross-platform dist.ini files)
+C<%p> path separator ('/' on Unix, '\\' on Win32... useful for cross-platform F<dist.ini> files)
 
 =item *
 
-C<%v> the dist version
+C<%v> the distribution version, if available (depending on the phase, the C<VersionProvider> plugin may not be able to return a version)
 
 =item *
 
@@ -162,12 +167,12 @@ C<%t> C<-TRIAL> if the release is a trial release, otherwise the empty string
 
 =item *
 
-C<%x> full path to the current perl interpreter (like $^X but from L<Config>)
+C<%x> full path to the current perl interpreter (like C<$^X> but from L<Config>)
 
 =back
 
-Additionally C<%s> is retained for backward compatibility.
-Each occurrence is replaced by a different value
+Additionally C<%s> is retained for backward compatibility (for those plugins that existed
+when it was documented).  Each occurrence is replaced by a different value
 (like the regular C<sprintf> function).
 Individual plugins define their own values for the positional replacement of C<%s>.
 
@@ -180,6 +185,17 @@ be used in a shell command, take care to use quotes or escapes!
 The very nature of these plugins is to execute code. Be mindful that your code
 may run on someone else's machine and don't be a jerk!
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Run>
+(or L<bug-Dist-Zilla-Plugin-Run@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Run@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
@@ -224,7 +240,7 @@ David Golden <dagolden@cpan.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
