@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::Plugin::Run::BeforeBuild;
 # ABSTRACT: execute a command of the distribution before build
 
-our $VERSION = '0.042';
+our $VERSION = '0.044';
 
 use Moose;
 with qw(
@@ -24,12 +24,12 @@ sub before_build {
 #pod =head1 SYNOPSIS
 #pod
 #pod   [Run::BeforeBuild]
-#pod   run = script/do_this.pl --version %s
+#pod   run = script/do_this.pl --version %v
 #pod   run = script/do_that.pl
 #pod
 #pod =head1 DESCRIPTION
 #pod
-#pod This plugin executes the specified command before building the dist.
+#pod This plugin executes the specified command before building the distribution.
 #pod
 #pod =head1 POSITIONAL PARAMETERS
 #pod
@@ -39,7 +39,7 @@ sub before_build {
 #pod For backward compatibility:
 #pod
 #pod =for :list
-#pod * The 1st C<%s> will be replaced by the dist version.
+#pod * The 1st C<%s> will be replaced by the distribution version.
 #pod
 #pod =cut
 
@@ -57,17 +57,17 @@ Dist::Zilla::Plugin::Run::BeforeBuild - execute a command of the distribution be
 
 =head1 VERSION
 
-version 0.042
+version 0.044
 
 =head1 SYNOPSIS
 
   [Run::BeforeBuild]
-  run = script/do_this.pl --version %s
+  run = script/do_this.pl --version %v
   run = script/do_that.pl
 
 =head1 DESCRIPTION
 
-This plugin executes the specified command before building the dist.
+This plugin executes the specified command before building the distribution.
 
 =head1 POSITIONAL PARAMETERS
 
@@ -80,15 +80,26 @@ For backward compatibility:
 
 =item *
 
-The 1st C<%s> will be replaced by the dist version.
+The 1st C<%s> will be replaced by the distribution version.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Run>
+(or L<bug-Dist-Zilla-Plugin-Run@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Run@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
