@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::Plugin::Run::BeforeRelease;
 # ABSTRACT: execute a command of the distribution before release
 
-our $VERSION = '0.042';
+our $VERSION = '0.044';
 
 use Moose;
 with qw(
@@ -25,12 +25,12 @@ sub before_release {
 #pod =head1 SYNOPSIS
 #pod
 #pod   [Run::BeforeRelease]
-#pod   run = script/myapp_before.pl %s
+#pod   run = script/myapp_before.pl %v %d
 #pod
 #pod or
 #pod
 #pod   [Run::BeforeRelease / MyAppBefore]
-#pod   run = script/myapp_before.pl %s
+#pod   run = script/myapp_before.pl %v %d
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -62,17 +62,17 @@ Dist::Zilla::Plugin::Run::BeforeRelease - execute a command of the distribution
 
 =head1 VERSION
 
-version 0.042
+version 0.044
 
 =head1 SYNOPSIS
 
   [Run::BeforeRelease]
-  run = script/myapp_before.pl %s
+  run = script/myapp_before.pl %v %d
 
 or
 
   [Run::BeforeRelease / MyAppBefore]
-  run = script/myapp_before.pl %s
+  run = script/myapp_before.pl %v %d
 
 =head1 DESCRIPTION
 
@@ -93,11 +93,22 @@ The 1st C<%s> will be replaced by the archive of the release.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Run>
+(or L<bug-Dist-Zilla-Plugin-Run@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Run@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
