@@ -1,9 +1,9 @@
 use strict;
 use warnings;
-
 package Dist::Zilla::Plugin::Run::Role::Runner;
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.042';
+our $VERSION = '0.044';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -54,6 +54,7 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
+        version => $VERSION,
         (map { $_ => $self->$_ ? 1 : 0 } qw(fatal_errors quiet)),
         map {
             @{ $self->$_ }
@@ -165,18 +166,15 @@ sub _run_cmd {
     # combine STDOUT and STDERR for ease of proxying through the logger
     my $pid = IPC::Open3::open3(my ($in, $out), undef, $command);
     binmode $out, ':crlf' if $^O eq 'MSWin32';
-    chomp(my @lines = <$out>); # logger appends its own newline
-    $self->${ $self->quiet ? \'log_debug' : \'log' }($_) for @lines;
+    while(defined(my $line = <$out>)){
+        chomp($line); # logger appends its own newline
+        $self->${ $self->quiet ? \'log_debug' : \'log' }($line);
+    }
 
     # zombie repellent
     waitpid($pid, 0);
 
     if (my $status = ($? >> 8)) {
-        if ($self->fatal_errors and $self->quiet and not $self->zilla->logger->get_debug) {
-            $self->log([ 'executed: %s', $command ]);
-            $self->log($_) for @lines;
-        }
-
         $self->${ $self->fatal_errors ? \'log_fatal' : $self->quiet ? \'log_debug' : \'log'}
             ([ 'command exited with status %s (%s)', $status, $? ]);
     }
@@ -245,7 +243,7 @@ sub build_formatter {
             $dir ? "$dir" : '';
         },
 
-        # dist name
+        # distribution name
         n => sub { $self->zilla->name },
 
         # backward compatibility (don't error)
@@ -262,7 +260,7 @@ sub build_formatter {
         $codes->{t} = sub { $self->_is_trial ? '-TRIAL' : '' };
     }
 
-    # positional replace (backward compatible)
+    # positional replacement of %s (backward compatible)
     if( my @pos = @{ $params->{pos} || [] } ){
         # where are you defined-or // operator?
         $codes->{s} = sub {
@@ -278,4 +276,3 @@ sub build_formatter {
 sub current_perl_path { $^X }
 
 1;
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
